/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.systemd1.Manager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef SYSTEMD_MANAGER_H
#define SYSTEMD_MANAGER_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.systemd1.Manager
 */
class OrgFreedesktopSystemd1ManagerInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.systemd1.Manager"; }

public:
    OrgFreedesktopSystemd1ManagerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopSystemd1ManagerInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<bool> EnableUnitFiles(const QStringList &files, bool runtime, bool force)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(files) << QVariant::fromValue(runtime) << QVariant::fromValue(force);
        return asyncCallWithArgumentList(QStringLiteral("EnableUnitFiles"), argumentList);
    }

    inline QDBusPendingReply<QString> GetUnitFileState(const QString &file)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(file);
        return asyncCallWithArgumentList(QStringLiteral("GetUnitFileState"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> LoadUnit(const QString &name)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name);
        return asyncCallWithArgumentList(QStringLiteral("LoadUnit"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> StartUnit(const QString &name, const QString &mode)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(name) << QVariant::fromValue(mode);
        return asyncCallWithArgumentList(QStringLiteral("StartUnit"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace freedesktop {
    namespace systemd1 {
      using Manager = ::OrgFreedesktopSystemd1ManagerInterface;
    }
  }
}

#endif
