/****************************************************************************
** Meta object code from reading C++ file 'groupmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdenetwork-filesharing-26.04.3/samba/filepropertiesplugin/groupmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'groupmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12GroupManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto GroupManager::qt_create_metaobjectdata<qt_meta_tag_ZN12GroupManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GroupManager",
        "isReadyChanged",
        "",
        "errorTextChanged",
        "errorExplanationChanged",
        "hasHelpfulActionChanged",
        "helpfulActionIconChanged",
        "helpfulActionTextChanged",
        "helpfulActionError",
        "error",
        "needsReboot",
        "performHelpfulAction",
        "errorText",
        "errorExplanation",
        "hasHelpfulAction",
        "helpfulActionIcon",
        "helpfulActionText",
        "ready"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'isReadyChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorTextChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorExplanationChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasHelpfulActionChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'helpfulActionIconChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'helpfulActionTextChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'helpfulActionError'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'needsReboot'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'performHelpfulAction'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'errorText'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'errorExplanation'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'hasHelpfulAction'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'helpfulActionIcon'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'helpfulActionText'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'ready'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GroupManager, qt_meta_tag_ZN12GroupManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GroupManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GroupManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GroupManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12GroupManagerE_t>.metaTypes,
    nullptr
} };

void GroupManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GroupManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->isReadyChanged(); break;
        case 1: _t->errorTextChanged(); break;
        case 2: _t->errorExplanationChanged(); break;
        case 3: _t->hasHelpfulActionChanged(); break;
        case 4: _t->helpfulActionIconChanged(); break;
        case 5: _t->helpfulActionTextChanged(); break;
        case 6: _t->helpfulActionError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->needsReboot(); break;
        case 8: _t->performHelpfulAction(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GroupManager::*)()>(_a, &GroupManager::isReadyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GroupManager::*)()>(_a, &GroupManager::errorTextChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GroupManager::*)()>(_a, &GroupManager::errorExplanationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GroupManager::*)()>(_a, &GroupManager::hasHelpfulActionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GroupManager::*)()>(_a, &GroupManager::helpfulActionIconChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GroupManager::*)()>(_a, &GroupManager::helpfulActionTextChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GroupManager::*)(const QString & )>(_a, &GroupManager::helpfulActionError, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GroupManager::*)()>(_a, &GroupManager::needsReboot, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_errorText; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->errorExplanation(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->m_hasHelpfulAction; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->m_helpfulActionIcon; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_helpfulActionText; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isReady(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_errorText, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->errorTextChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_hasHelpfulAction, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->hasHelpfulActionChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_helpfulActionIcon, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->helpfulActionIconChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_helpfulActionText, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->helpfulActionTextChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *GroupManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GroupManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GroupManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GroupManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void GroupManager::isReadyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GroupManager::errorTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GroupManager::errorExplanationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void GroupManager::hasHelpfulActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void GroupManager::helpfulActionIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void GroupManager::helpfulActionTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void GroupManager::helpfulActionError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void GroupManager::needsReboot()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
