/****************************************************************************
** Meta object code from reading C++ file 'aceobject.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdenetwork-filesharing-26.04.3/samba/aclproperties/aceobject.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'aceobject.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9ACEObjectE_t {};
} // unnamed namespace

template <> constexpr inline auto ACEObject::qt_create_metaobjectdata<qt_meta_tag_ZN9ACEObjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ACEObject",
        "typeChanged",
        "",
        "inheritanceChanged",
        "noPropagateChanged",
        "takeOwnershipChanged",
        "changePermissionsChanged",
        "readPermissionsChanged",
        "canDeleteChanged",
        "canDeleteDataChanged",
        "writeExtendedAttributesChanged",
        "writeAttributesChanged",
        "appendDataChanged",
        "writeDataChanged",
        "readExtendedAttributesChanged",
        "readAttributesChanged",
        "readDataChanged",
        "executeChanged",
        "inherited",
        "type",
        "inheritance",
        "noPropagate",
        "takeOwnership",
        "changePermissions",
        "readPermissions",
        "canDelete",
        "canDeleteData",
        "writeExtendedAttributes",
        "writeAttributes",
        "appendData",
        "writeData",
        "readExtendedAttributes",
        "readAttributes",
        "readData",
        "execute",
        "Type",
        "Deny",
        "Allow",
        "Inheritance",
        "SubfoldersFiles",
        "Subfolders",
        "Files",
        "FolderSubfoldersFiles",
        "FolderSubfolders",
        "FolderFiles",
        "None"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inheritanceChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noPropagateChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'takeOwnershipChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changePermissionsChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readPermissionsChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canDeleteChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canDeleteDataChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'writeExtendedAttributesChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'writeAttributesChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appendDataChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'writeDataChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readExtendedAttributesChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readAttributesChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readDataChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'executeChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'inherited'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'type'
        QtMocHelpers::PropertyData<uint>(19, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'inheritance'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'noPropagate'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'takeOwnership'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'changePermissions'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'readPermissions'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'canDelete'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 6),
        // property 'canDeleteData'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 7),
        // property 'writeExtendedAttributes'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 8),
        // property 'writeAttributes'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 9),
        // property 'appendData'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 10),
        // property 'writeData'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 11),
        // property 'readExtendedAttributes'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 12),
        // property 'readAttributes'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 13),
        // property 'readData'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 14),
        // property 'execute'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 15),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(35, 35, QMC::EnumIsScoped).add({
            {   36, Type::Deny },
            {   37, Type::Allow },
        }),
        // enum 'Inheritance'
        QtMocHelpers::EnumData<enum Inheritance>(38, 38, QMC::EnumIsScoped).add({
            {   39, Inheritance::SubfoldersFiles },
            {   40, Inheritance::Subfolders },
            {   41, Inheritance::Files },
            {   42, Inheritance::FolderSubfoldersFiles },
            {   43, Inheritance::FolderSubfolders },
            {   44, Inheritance::FolderFiles },
            {   45, Inheritance::None },
        }),
    };
    return QtMocHelpers::metaObjectData<ACEObject, qt_meta_tag_ZN9ACEObjectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ACEObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ACEObjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ACEObjectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9ACEObjectE_t>.metaTypes,
    nullptr
} };

void ACEObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ACEObject *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->typeChanged(); break;
        case 1: _t->inheritanceChanged(); break;
        case 2: _t->noPropagateChanged(); break;
        case 3: _t->takeOwnershipChanged(); break;
        case 4: _t->changePermissionsChanged(); break;
        case 5: _t->readPermissionsChanged(); break;
        case 6: _t->canDeleteChanged(); break;
        case 7: _t->canDeleteDataChanged(); break;
        case 8: _t->writeExtendedAttributesChanged(); break;
        case 9: _t->writeAttributesChanged(); break;
        case 10: _t->appendDataChanged(); break;
        case 11: _t->writeDataChanged(); break;
        case 12: _t->readExtendedAttributesChanged(); break;
        case 13: _t->readAttributesChanged(); break;
        case 14: _t->readDataChanged(); break;
        case 15: _t->executeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::typeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::inheritanceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::noPropagateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::takeOwnershipChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::changePermissionsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::readPermissionsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::canDeleteChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::canDeleteDataChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::writeExtendedAttributesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::writeAttributesChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::appendDataChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::writeDataChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::readExtendedAttributesChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::readAttributesChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::readDataChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ACEObject::*)()>(_a, &ACEObject::executeChanged, 15))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->m_inherited; break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->type(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->inheritance(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->noPropagate(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->takeOwnership(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->changePermissions(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->readPermissions(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->canDelete(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->canDeleteData(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->writeExtendedAttributes(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->writeAttributes(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->appendData(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->writeData(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->readExtendedAttributes(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->readAttributes(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->readData(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->execute(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setType(*reinterpret_cast<uint*>(_v)); break;
        case 2: _t->setInheritance(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setNoPropagate(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->set_takeOwnership(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->set_changePermissions(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->set_readPermissions(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->set_canDelete(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->set_canDeleteData(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->set_writeExtendedAttributes(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->set_writeAttributes(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->set_appendData(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->set_writeData(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->set_readExtendedAttributes(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->set_readAttributes(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->set_readData(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->set_execute(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ACEObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ACEObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ACEObjectE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ACEObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void ACEObject::typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ACEObject::inheritanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ACEObject::noPropagateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ACEObject::takeOwnershipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ACEObject::changePermissionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ACEObject::readPermissionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ACEObject::canDeleteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ACEObject::canDeleteDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ACEObject::writeExtendedAttributesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ACEObject::writeAttributesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ACEObject::appendDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ACEObject::writeDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void ACEObject::readExtendedAttributesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void ACEObject::readAttributesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void ACEObject::readDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void ACEObject::executeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
