/****************************************************************************
** Meta object code from reading C++ file 'sambausershareplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdenetwork-filesharing-26.04.3/samba/filepropertiesplugin/sambausershareplugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sambausershareplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ShareContextE_t {};
} // unnamed namespace

template <> constexpr inline auto ShareContext::qt_create_metaobjectdata<qt_meta_tag_ZN12ShareContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ShareContext",
        "enabledChanged",
        "",
        "guestEnabledChanged",
        "nameChanged",
        "newShareName",
        "QUrl",
        "url",
        "isNameFree",
        "name",
        "enabled",
        "canEnableGuest",
        "guestEnabled",
        "maximumNameLength",
        "path"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'guestEnabledChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newShareName'
        QtMocHelpers::SlotData<QString(const QUrl &)>(5, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Method 'isNameFree'
        QtMocHelpers::MethodData<bool(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'canEnableGuest'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guestEnabled'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'maximumNameLength'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'path'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ShareContext, qt_meta_tag_ZN12ShareContextE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ShareContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ShareContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ShareContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ShareContextE_t>.metaTypes,
    nullptr
} };

void ShareContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ShareContext *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->guestEnabledChanged(); break;
        case 2: _t->nameChanged(); break;
        case 3: { QString _r = _t->newShareName((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->isNameFree((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ShareContext::*)()>(_a, &ShareContext::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShareContext::*)()>(_a, &ShareContext::guestEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShareContext::*)()>(_a, &ShareContext::nameChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canEnableGuest(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->guestEnabled(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->maximumNameLength(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setGuestEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ShareContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ShareContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ShareContextE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ShareContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void ShareContext::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ShareContext::guestEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ShareContext::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN20SambaUserSharePluginE_t {};
} // unnamed namespace

template <> constexpr inline auto SambaUserSharePlugin::qt_create_metaobjectdata<qt_meta_tag_ZN20SambaUserSharePluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SambaUserSharePlugin",
        "readyChanged",
        "",
        "addressListChanged",
        "needsRebootChanged",
        "pagePushed",
        "url",
        "reinitialize",
        "isSambaInstalled",
        "reboot",
        "showSambaStatus",
        "copyAddressToClipboard",
        "address",
        "changed",
        "dirty",
        "ready",
        "needsReboot",
        "addressList",
        "userManager",
        "UserManager*",
        "userPermissionModel",
        "UserPermissionModel*",
        "shareContext",
        "ShareContext*",
        "permissionsHelper",
        "PermissionsHelper*",
        "serviceHelper",
        "ServiceHelper*",
        "groupManager",
        "GroupManager*",
        "bugReportUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'readyChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addressListChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'needsRebootChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pagePushed'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'reinitialize'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'isSambaInstalled'
        QtMocHelpers::MethodData<bool()>(8, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'reboot'
        QtMocHelpers::MethodData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'showSambaStatus'
        QtMocHelpers::MethodData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'copyAddressToClipboard'
        QtMocHelpers::MethodData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'dirty'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 13),
        // property 'ready'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'needsReboot'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'addressList'
        QtMocHelpers::PropertyData<QStringList>(17, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'userManager'
        QtMocHelpers::PropertyData<UserManager*>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'userPermissionModel'
        QtMocHelpers::PropertyData<UserPermissionModel*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'shareContext'
        QtMocHelpers::PropertyData<ShareContext*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'permissionsHelper'
        QtMocHelpers::PropertyData<PermissionsHelper*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'serviceHelper'
        QtMocHelpers::PropertyData<ServiceHelper*>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'groupManager'
        QtMocHelpers::PropertyData<GroupManager*>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'bugReportUrl'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SambaUserSharePlugin, qt_meta_tag_ZN20SambaUserSharePluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SambaUserSharePlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<KPropertiesDialogPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20SambaUserSharePluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20SambaUserSharePluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20SambaUserSharePluginE_t>.metaTypes,
    nullptr
} };

void SambaUserSharePlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SambaUserSharePlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->readyChanged(); break;
        case 1: _t->addressListChanged(); break;
        case 2: _t->needsRebootChanged(); break;
        case 3: _t->pagePushed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->reinitialize(); break;
        case 5: { bool _r = _t->isSambaInstalled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->reboot(); break;
        case 7: _t->showSambaStatus(); break;
        case 8: _t->copyAddressToClipboard((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SambaUserSharePlugin::*)()>(_a, &SambaUserSharePlugin::readyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SambaUserSharePlugin::*)()>(_a, &SambaUserSharePlugin::addressListChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SambaUserSharePlugin::*)()>(_a, &SambaUserSharePlugin::needsRebootChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SambaUserSharePlugin::*)(const QString & )>(_a, &SambaUserSharePlugin::pagePushed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SambaUserSharePlugin::*)()>(_a, &SambaUserSharePlugin::reinitialize, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< GroupManager* >(); break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PermissionsHelper* >(); break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ServiceHelper* >(); break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ShareContext* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UserManager* >(); break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UserPermissionModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isDirty(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isReady(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->needsReboot(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->m_addressList; break;
        case 4: *reinterpret_cast<UserManager**>(_v) = _t->m_userManager; break;
        case 5: *reinterpret_cast<UserPermissionModel**>(_v) = _t->m_model; break;
        case 6: *reinterpret_cast<ShareContext**>(_v) = _t->m_context; break;
        case 7: *reinterpret_cast<PermissionsHelper**>(_v) = _t->m_permissionsHelper; break;
        case 8: *reinterpret_cast<ServiceHelper**>(_v) = _t->m_serviceHelper; break;
        case 9: *reinterpret_cast<GroupManager**>(_v) = _t->m_groupManager; break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->bugReportUrl(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDirty(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setNeedsReboot(*reinterpret_cast<bool*>(_v)); break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_addressList, *reinterpret_cast<QStringList*>(_v)))
                Q_EMIT _t->addressListChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *SambaUserSharePlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SambaUserSharePlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20SambaUserSharePluginE_t>.strings))
        return static_cast<void*>(this);
    return KPropertiesDialogPlugin::qt_metacast(_clname);
}

int SambaUserSharePlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPropertiesDialogPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void SambaUserSharePlugin::readyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SambaUserSharePlugin::addressListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SambaUserSharePlugin::needsRebootChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SambaUserSharePlugin::pagePushed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void SambaUserSharePlugin::reinitialize()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
namespace CheckNotifySignalValidity_ZN20SambaUserSharePluginE {
template<typename T> using has_nullary_changed = decltype(std::declval<T>().changed());
template<typename T> using has_unary_changed = decltype(std::declval<T>().changed(std::declval<bool>()));
static_assert(qxp::is_detected_v<has_nullary_changed, SambaUserSharePlugin> || qxp::is_detected_v<has_unary_changed, SambaUserSharePlugin>,
              "NOTIFY signal changed does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
